@@ -376,7 +376,6 @@ def dep_zapdeps(
     # c) contains masked installed packages
     # d) is the first item
 
-    no_new_slots = []
     preferred_in_graph = []
     preferred_installed = preferred_in_graph
     preferred_any_slot = preferred_in_graph
@@ -392,7 +391,6 @@ def dep_zapdeps(
     # unsat_use_* must come after preferred_non_installed
     # for correct ordering in cases like || ( foo[a] foo[b] ).
     choice_bins = (
-        no_new_slots,
         preferred_in_graph,
         preferred_non_installed,
         unsat_use_in_graph,
@@ -691,9 +689,7 @@ def dep_zapdeps(
                     other.append(this_choice)
                 else:
                     if all_use_satisfied:
-                        if new_slot_count == 0 and not want_update:
-                            no_new_slots.append(this_choice)
-                        elif all_in_graph:
+                        if all_in_graph:
                             preferred_in_graph.append(this_choice)
                         elif all_installed:
                             if all_installed_slots:
@@ -1084,7 +1080,7 @@ def dep_wordreduce(mydeplist, mysettings, mydbapi, mode, use_cache=1):
                         mydep = x
                 else:
                     mydep = mydbapi.match(deplist[mypos], use_cache=use_cache)
-                if mydep != None:
+                if mydep is not None:
                     tmp = len(mydep) >= 1
                     if deplist[mypos][0] == "!":
                         tmp = False
